# Its4landPublicApi.ModelsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getModels**](ModelsApi.md#getModels) | **GET** /models | Returns a list of models.
[**getModelsByUID**](ModelsApi.md#getModelsByUID) | **GET** /models/{model_uid} | Returns a single model
[**getModelsClassesByModel**](ModelsApi.md#getModelsClassesByModel) | **GET** /models/{model_uid}/modelclasses | Returns the model classes of the classifier.
[**newModel**](ModelsApi.md#newModel) | **POST** /models | Create a new model
[**newModelClassUnderModel**](ModelsApi.md#newModelClassUnderModel) | **POST** /models/{model_uid}/modelclasses | Create a new ModelClass under a model
[**updateModels**](ModelsApi.md#updateModels) | **PATCH** /models/{model_uid} | Updates some attributes of a model


<a name="getModels"></a>
# **getModels**
> [ModelsEndpointType] getModels(opts, responseAsResult = *false*)

Returns a list of models.

Returns a list of models.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'uid': ["uid_example"], // [String] | Comma separated list of model UID
  'name': ["name_example"], // [String] | Comma separated list of model names
  'tools': ["tools_example"], // [String] | Comma separated list tool names which can make use of the model.
  'projects': ["projects_example"], // [String] | Comma separated list of project UID
  'tags': ["tags_example"], // [String] | Comma separated list of tags
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getModels(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **uid** | [**[String]**](String.md)| Comma separated list of model UID | [optional] 
 **name** | [**[String]**](String.md)| Comma separated list of model names | [optional] 
 **tools** | [**[String]**](String.md)| Comma separated list tool names which can make use of the model. | [optional] 
 **projects** | [**[String]**](String.md)| Comma separated list of project UID | [optional] 
 **tags** | [**[String]**](String.md)| Comma separated list of tags | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**[ModelsEndpointType]**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getModelsByUID"></a>
# **getModelsByUID**
> ModelsEndpointType getModelsByUID(modelUid, opts, responseAsResult = *false*)

Returns a single model

Returns a single model

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var modelUid = "modelUid_example"; // String | Model  UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getModelsByUID(modelUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **modelUid** | **String**| Model  UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**ModelsEndpointType**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getModelsClassesByModel"></a>
# **getModelsClassesByModel**
> [ModelClassesEndpointType] getModelsClassesByModel(modelUid, opts, responseAsResult = *false*)

Returns the model classes of the classifier.

Returns the model classes of the classifier.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var modelUid = "modelUid_example"; // String | Model  UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getModelsClassesByModel(modelUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **modelUid** | **String**| Model  UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**[ModelClassesEndpointType]**](ModelClassesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newModel"></a>
# **newModel**
> ModelsEndpointType newModel(newmodel, opts, responseAsResult = *false*)

Create a new model

Create a new model. The model can be assigned to a project via the patch://project method. To add a new SpatialSources , the content of Models  must be stored in advanced via the ContentItem endpoint

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var newmodel = new Its4landPublicApi.ModelsPostRequest(); // ModelsPostRequest | New Model data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newModel(newmodel, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newmodel** | [**ModelsPostRequest**](ModelsPostRequest.md)| New Model data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ModelsEndpointType**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newModelClassUnderModel"></a>
# **newModelClassUnderModel**
> ModelClassesEndpointType newModelClassUnderModel(modelUid, newmodelclass, opts, responseAsResult = *false*)

Create a new ModelClass under a model

Create a new ModelClass under a model

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var modelUid = "modelUid_example"; // String | Model  UID

var newmodelclass = new Its4landPublicApi.ModelClassesPostRequest(); // ModelClassesPostRequest | New ModelClass data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newModelClassUnderModel(modelUid, newmodelclass, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **modelUid** | **String**| Model  UID | 
 **newmodelclass** | [**ModelClassesPostRequest**](ModelClassesPostRequest.md)| New ModelClass data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ModelClassesEndpointType**](ModelClassesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateModels"></a>
# **updateModels**
> ModelsEndpointType updateModels(modelUid, patchmodel, opts, responseAsResult = *false*)

Updates some attributes of a model

Updates some attributes of a model

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ModelsApi();

var modelUid = "modelUid_example"; // String | Model  UID

var patchmodel = new Its4landPublicApi.RFC6902PatchRequest(); // RFC6902PatchRequest | Update data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.updateModels(modelUid, patchmodel, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **modelUid** | **String**| Model  UID | 
 **patchmodel** | [**RFC6902PatchRequest**](RFC6902PatchRequest.md)| Update data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ModelsEndpointType**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

