# Its4landPublicApi.ProjectsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addTagToProject**](ProjectsApi.md#addTagToProject) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
[**delProjectByUID**](ProjectsApi.md#delProjectByUID) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
[**detachProjectModel**](ProjectsApi.md#detachProjectModel) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
[**detachProjectSpatialSource**](ProjectsApi.md#detachProjectSpatialSource) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
[**detachProjectTag**](ProjectsApi.md#detachProjectTag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
[**getConnectedObjectsByProjectUID**](ProjectsApi.md#getConnectedObjectsByProjectUID) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
[**getModelsByProjectUID**](ProjectsApi.md#getModelsByProjectUID) | **GET** /projects/{project_uid}/Models | Returns the models of a project
[**getProjectTagsByProjectUID**](ProjectsApi.md#getProjectTagsByProjectUID) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
[**getProjects**](ProjectsApi.md#getProjects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
[**getProjectsByUID**](ProjectsApi.md#getProjectsByUID) | **GET** /projects/{project_uid} | Getting single Projects by its UID
[**getSpatialSourceByProjectUID**](ProjectsApi.md#getSpatialSourceByProjectUID) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
[**newModelUnderProject**](ProjectsApi.md#newModelUnderProject) | **POST** /projects/{project_uid}/Models | Create a new model
[**newProject**](ProjectsApi.md#newProject) | **POST** /projects | Create a new project
[**newSpatialSourceUnderProject**](ProjectsApi.md#newSpatialSourceUnderProject) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
[**updateProjects**](ProjectsApi.md#updateProjects) | **PATCH** /projects/{project_uid} | Update a project


<a name="addTagToProject"></a>
# **addTagToProject**
> ProjectsEndpointType addTagToProject(projectUid, newtag, opts, responseAsResult = *false*)

Adds a tag to the project

Creates a new tag and attach it to the project. If the tag already exist, the existing tag will be attached to the project.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var newtag = new Its4landPublicApi.TagsPostRequest(); // TagsPostRequest | New Tag data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.addTagToProject(projectUid, newtag, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **newtag** | [**TagsPostRequest**](TagsPostRequest.md)| New Tag data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="delProjectByUID"></a>
# **delProjectByUID**
> ProjectsEndpointType delProjectByUID(projectUid, opts, responseAsResult = *false*)

Deletes a single e project by its UID

A single project is deleted. This endpoint deletes the project itself and the connected to subordered data like SpatialSources, etc. The subordered data itself are not deleted

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | UID of the project

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.delProjectByUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| UID of the project | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectModel"></a>
# **detachProjectModel**
> ProjectsEndpointType detachProjectModel(projectUid, modelUid, opts, responseAsResult = *false*)

Removes a model from a project.

Removes a model from a project. By default only the link between model and project is removed.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var modelUid = "modelUid_example"; // String | Model UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'forceDelete': "forceDelete_example" // String | Deletes the model resource. ********* What's about subordinate resources? *********
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.detachProjectModel(projectUid, modelUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **modelUid** | **String**| Model UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **forceDelete** | **String**| Deletes the model resource. ********* What&#39;s about subordinate resources? ********* | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectSpatialSource"></a>
# **detachProjectSpatialSource**
> ProjectsEndpointType detachProjectSpatialSource(projectUid, spatialsourceUid, opts, responseAsResult = *false*)

Removes a spatialsource from a project.

Removes a spatial from a project. By default only the link between spatialsource and project is removed.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var spatialsourceUid = "spatialsourceUid_example"; // String | SpatialSource UID

var opts = { 
  'forceDelete': "forceDelete_example" // String | Deletes the spatialsource resource. ********* What's about subordinate resources? *********
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.detachProjectSpatialSource(projectUid, spatialsourceUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **spatialsourceUid** | **String**| SpatialSource UID | 
 **forceDelete** | **String**| Deletes the spatialsource resource. ********* What&#39;s about subordinate resources? ********* | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectTag"></a>
# **detachProjectTag**
> ProjectsEndpointType detachProjectTag(projectUid, tag, opts, responseAsResult = *false*)

Removes a tag from a project.

Removes a tag from a project. By default only the link between tag and project is removed.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var tag = "tag_example"; // String | tag value

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'forceDelete': "forceDelete_example" // String | Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. *********
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.detachProjectTag(projectUid, tag, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **tag** | **String**| tag value | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **forceDelete** | **String**| Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getConnectedObjectsByProjectUID"></a>
# **getConnectedObjectsByProjectUID**
> ConnectedObjectsEndpointType getConnectedObjectsByProjectUID(projectUid, opts, responseAsResult = *false*)

Returns an array of connect objects

Returns an array of connect objects of a project. For each connected object the endpoint returns the type, name and uuid

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getConnectedObjectsByProjectUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**ConnectedObjectsEndpointType**](ConnectedObjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getModelsByProjectUID"></a>
# **getModelsByProjectUID**
> [ModelsEndpointType] getModelsByProjectUID(projectUid, opts, responseAsResult = *false*)

Returns the models of a project

Returns the models of a project

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getModelsByProjectUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**[ModelsEndpointType]**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjectTagsByProjectUID"></a>
# **getProjectTagsByProjectUID**
> TagsListResponse getProjectTagsByProjectUID(projectUid, opts, responseAsResult = *false*)

Returns the tags of a project.

Is this method really necessary? Returns the tags of a project.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getProjectTagsByProjectUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 


### Return type

[**TagsListResponse**](TagsListResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjects"></a>
# **getProjects**
> ProjectsEndpointType getProjects(opts, responseAsResult = *false*)

Get a GeoJSON structure containing a list of Projects.

Get a GeoJSON structure containing a list of Projects. A single project is modeled as a GeoJSON feature.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'uid': ["uid_example"], // [String] | Comma separated list of UID
  'name': ["name_example"], // [String] | Comma separated list of names
  'aoi': "aoi_example", // String | Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1
  'tags': ["tags_example"], // [String] | Comma separated list of tags
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getProjects(opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **uid** | [**[String]**](String.md)| Comma separated list of UID | [optional] 
 **name** | [**[String]**](String.md)| Comma separated list of names | [optional] 
 **aoi** | **String**| Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 | [optional] 
 **tags** | [**[String]**](String.md)| Comma separated list of tags | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjectsByUID"></a>
# **getProjectsByUID**
> ProjectsEndpointType getProjectsByUID(projectUid, opts, responseAsResult = *false*)

Getting single Projects by its UID

Getting single Projects by its UID. The project is modeled as a feature in a GeoJSON structure.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | UID of the project

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getProjectsByUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| UID of the project | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSpatialSourceByProjectUID"></a>
# **getSpatialSourceByProjectUID**
> [SpatialSourcesEndpointType] getSpatialSourceByProjectUID(projectUid, opts, responseAsResult = *false*)

Returns the SpatialSources of a Project.

Returns the SpatialSources of a Project.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'page': 56, // Number | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
  'sort': "sort_example", // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
  'fields': ["fields_example"], // [String] | Comma separated list of field names
  'embed': ["embed_example"] // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getSpatialSourceByProjectUID(projectUid, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **page** | **Number**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional] 
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional] 
 **fields** | [**[String]**](String.md)| Comma separated list of field names | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 


### Return type

[**[SpatialSourcesEndpointType]**](SpatialSourcesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newModelUnderProject"></a>
# **newModelUnderProject**
> ProjectsEndpointType newModelUnderProject(projectUid, newmodel, opts, responseAsResult = *false*)

Create a new model

Create a new model.  To add a new Model , the content of Models  must be stored in advanced via the ContentItem endpoint

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var newmodel = new Its4landPublicApi.ModelsPostRequest(); // ModelsPostRequest | New model data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newModelUnderProject(projectUid, newmodel, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **newmodel** | [**ModelsPostRequest**](ModelsPostRequest.md)| New model data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newProject"></a>
# **newProject**
> ProjectsEndpointType newProject(newproject, opts, responseAsResult = *false*)

Create a new project

Create a new project. The new project is modeled as a feature in a GeoJSON structure. Currently only one project feature is allowed.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var newproject = new Its4landPublicApi.ProjectsPostRequest(); // ProjectsPostRequest | New project data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newProject(newproject, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newproject** | [**ProjectsPostRequest**](ProjectsPostRequest.md)| New project data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newSpatialSourceUnderProject"></a>
# **newSpatialSourceUnderProject**
> ProjectsEndpointType newSpatialSourceUnderProject(projectUid, newspatialsource, opts, responseAsResult = *false*)

Create a new SpatialSource

Create a new SpatialSource. To add a new SpatialSource , the content of SpatialSource  must be stored in advanced via the ContentItem endpoint

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID

var newspatialsource = new Its4landPublicApi.SpatialSourcesPostRequest(); // SpatialSourcesPostRequest | New SpatialSource data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.newSpatialSourceUnderProject(projectUid, newspatialsource, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID | 
 **newspatialsource** | [**SpatialSourcesPostRequest**](SpatialSourcesPostRequest.md)| New SpatialSource data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateProjects"></a>
# **updateProjects**
> ProjectsEndpointType updateProjects(projectUid, patchproject, opts, responseAsResult = *false*)

Update a project

Updates some attributes of a project.

### Example
```javascript
var Its4landPublicApi = require('its4land_public_api');

var apiInstance = new Its4landPublicApi.ProjectsApi();

var projectUid = "projectUid_example"; // String | Project UID to be patched

var patchproject = new Its4landPublicApi.RFC6902PatchRequest(); // RFC6902PatchRequest | Update data

var opts = { 
  'envelope': "envelope_example", // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
  'embed': ["embed_example"], // [String] | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
  'i4lProcessUid': "i4lProcessUid_example" // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
};

var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.updateProjects(projectUid, patchproject, opts, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID to be patched | 
 **patchproject** | [**RFC6902PatchRequest**](RFC6902PatchRequest.md)| Update data | 
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] 
 **embed** | [**[String]**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional] 
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional] 


### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

